# Using HappyFeat

## Using a trained classifier

After the [training step](train.md), *HappyFeat* can automatically generate an OpenViBE scenario to use in an online BCI experiment.

To do so, click on the training attempt corresponding to the set of features and training score you want to use, and click on "*Use selected classifier (online scen.)*".

The generated scenario *sc3-online.xml* will then be available in the current workspace folder.